@@ -8,6 +8,9 @@ from xarray import DataArray
 from bmi_geotiff import GeoTiff
 
 TEST_FILE = "RGB.byte.tif"
+TEST_URL = (
+    "https://csdms.colorado.edu/data/LE07_L1GT_103064_20210412_20210412_02_RT_B1.TIF"
+)
 
 
 def test_instantiate_without_filename():
@@ -38,9 +41,27 @@ def test_with_filename_as_keyword(shared_datadir):
     assert isinstance(g.da, DataArray)
 
 
+def test_with_filename_as_url():
+    g = GeoTiff(TEST_URL)
+    assert isinstance(g, GeoTiff)
+    assert g.filename == TEST_URL
+    assert isinstance(g.da, DataArray)
+
+
 def test_open(shared_datadir):
     g = GeoTiff()
     f = Path(shared_datadir) / TEST_FILE
     g.open(f)
     assert g.filename == f
     assert isinstance(g.da, DataArray)
+
+
+def test_squeeze_band():
+    g = GeoTiff(TEST_URL)
+    assert g.da.ndim != 3
+
+
+def test_no_squeeze_band(shared_datadir):
+    f = Path(shared_datadir) / TEST_FILE
+    g = GeoTiff(f)
+    assert g.da.band.size == 3
